ProtobufContainer class abstract

Implementers

Constructors

ProtobufContainer()

Properties

binaryDescriptorName → String
no setter
classname → String?
no setter
dottedName → String
The fully qualified name with a leading '.'.
no setter
fieldPath → List<int>?
The field path contains the field IDs and indices (for repeated fields) that lead to the proto member corresponding to a piece of generated code. Repeated fields in the descriptor are further identified by the index of the message in question. For more information see https://github.com/protocolbuffers/protobuf/blob/master/src/google/protobuf/descriptor.proto#L728
no setter
fileGen → FileGenerator?
The generator of the .pb.dart file defining this entity.
no setter
fileImportPrefix → String
no setter
fullName → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
interfaceName → String?
The name of the Dart abstract interface to generate.
no setter
package → String
no setter
parent → ProtobufContainer?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toplevelParent → ProtobufContainer?
The top-level parent of this entity, or itself if it is a top-level entity.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited