ReCase class

An instance of text to be re-cased. Forked and modified from recase 4.1.0

Constructors

ReCase(String text)

Properties

camelCase → String
camelCase
no setter
constantCase → String
CONSTANT_CASE
no setter
dotCase → String
dot.case
no setter
hashCode → int
The hash code for this object.
no setterinherited
headerCase → String
Header-Case
no setter
originalText ↔ String
getter/setter pair
paramCase → String
param-case
no setter
pascalCase → String
PascalCase
no setter
pathCase → String
path/case
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sentenceCase → String
Sentence case
no setter
snakeCase → String
snake_case
no setter
symbolSet → Set<String>
final
titleCase → String
Title Case
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited